@@ -1,10 +1,11 @@
 import inspect
 import datetime
 from base64 import b64encode
+from enum import Enum
 
 from pydantic import BaseModel
 
-from telectron.utils import datetime_to_timestamp
+from telegram_types.utils import datetime_to_timestamp
 
 
 class Base(BaseModel):
@@ -21,6 +22,8 @@ class Base(BaseModel):
                 v = b64encode(v).decode()
             if type(v) == datetime.datetime:
                 v = datetime_to_timestamp(v)
+            if isinstance(v, Enum):
+                v = v.value
             cls_dict[a] = ( field_type.from_telegram_type(v)
                             if inspect.isclass(field_type) and issubclass(field_type, Base)
                             else v )
