@@ -1,8 +1,8 @@
 from typing import Optional
 
 from pydantic import BaseModel
-from telectron.enums.message_media_type import MessageMediaType as MediaType
-from telectron.enums.poll_type import PollType
+from telegram_types.enums.message_media_type import MessageMediaType as MediaType
+from telegram_types.enums.poll_type import PollType
 
 
 class AnimationAttributes(BaseModel):
