@@ -2,7 +2,7 @@ from typing import Optional, List
 
 from telegram_types.types import Restriction, ChatPhoto
 from telegram_types.base import Base
-from telectron.enums.chat_type import ChatType
+from telegram_types.enums.chat_type import ChatType
 
 
 class ChatPermissions(Base):
