@@ -27,6 +27,13 @@ class KeyboardButton(Base):
     request_contact: Optional[bool]
     request_location: Optional[bool]
 
+    @classmethod
+    def from_telegram_type_dict(cls, obj) -> dict:
+        if isinstance(obj, str):
+            return {'text': obj}
+        else:
+            return super().from_telegram_type_dict(obj)
+
 
 class ReplyKeyboardMarkup(Base):
     keyboard: List[List[KeyboardButton]]
@@ -35,6 +42,15 @@ class ReplyKeyboardMarkup(Base):
     selective: Optional[bool]
     placeholder: Optional[str]
 
+    @classmethod
+    def from_telegram_type_dict(cls, obj) -> dict:
+        cls_dict = super().from_telegram_type_dict(obj)
+        if obj.keyboard:
+            cls_dict['keyboard'] = [[
+                KeyboardButton.from_telegram_type(b) for b in row
+            ] for row in obj.keyboard]
+        return cls_dict
+
 
 class ReplyKeyboardRemove(Base):
     selective: Optional[bool]
