@@ -2,7 +2,7 @@ from typing import List, Optional
 
 from telegram_types.base import Base
 
-from telectron.enums.poll_type import PollType
+from telegram_types.enums.poll_type import PollType
 
 
 class PollOption(Base):
