@@ -90,8 +90,10 @@ class Message(Base):
         if obj.web_page:
             cls_dict['web_page'] = True
         if obj.reply_markup:
-            if obj.reply_markup.inline_keyboard:
+            if hasattr(obj.reply_markup, 'inline_keyboard'):
                 cls_dict['reply_markup'] = InlineKeyboardMarkup.from_telegram_type(obj.reply_markup)
+            elif hasattr(obj.reply_markup, 'keyboard'):
+                cls_dict['reply_markup'] = ReplyKeyboardMarkup.from_telegram_type(obj.reply_markup)
             else:
                 cls_dict['reply_markup'] = None
         return cls_dict
