@@ -3,7 +3,7 @@ from typing import Optional, List
 from telegram_types.types import Restriction, ChatPhoto
 from telegram_types.base import Base
 
-from telectron.enums import UserStatus as Status
+from telegram_types.enums import UserStatus as Status
 
 
 class User(Base):
